@@ -19,9 +19,10 @@
 
 import sys, os, time, select, logging
 import modulefinder
-import watch_files
-import utils
-from utils import get_caller as my
+from . import watch_files
+from . import utils
+from .utils import get_caller as my
+from .utils import ses
 
 class watch(object):
 	"""
@@ -78,7 +79,7 @@ class watch(object):
 		rebuild = False
 		wparams = params.copy()
 		wparams['commit'] = False
-		for path in self._watch.paths_open.keys():
+		for path in list(self._watch.paths_open):
 			if path in self.modules:
 				continue
 			try:
@@ -90,7 +91,7 @@ class watch(object):
 
 		#  Find all the modules that are new and should be watched
 		#
-		for path in self.modules.keys():
+		for path in list(self.modules):
 			if path not in self._watch.paths_open:
 				try:
 					self._watch.add(path, **wparams)
@@ -131,8 +132,8 @@ class watch(object):
 						changes[name] = [path]
 			else:
 				log.warning("%s Path '%s' had no matching watch entry", my(self), path)
-		names = changes.keys()
-		log.debug("%s Change was to %d name%s", my(self), len(names), '' if len(names) == 1 else 's')
+		names = list(changes)
+		log.debug("%s Change was to %d name%s", my(self), len(names), ses(len(names)))
 		names.sort()
 		resp = []
 		for name in names:
@@ -233,7 +234,7 @@ class watch(object):
 			log.debug("%s Command '%s' added for '%s'", my(self), command, name)
 			self.modules[command] = [name]
 			rebuild = True
-		for modname, mod in finder.modules.iteritems():
+		for modname, mod in list(finder.modules.items()):
 			path = mod.__file__
 			if not path:
 				log.debug("%s Skipping module '%s' -- no __file__ in module", my(self), modname)
@@ -265,7 +266,7 @@ class watch(object):
 			raise Exception("Command '%s' has never been added" % (name,))
 		del self.names[name]
 		rebuild = False
-		for path in self.modules.keys():
+		for path in list(self.modules):
 			if name in self.modules[path]:
 				self.modules[path].remove(name)
 			if len(self.modules[path]) == 0:
@@ -282,65 +283,3 @@ class watch(object):
 		a rename, as, for example, is done by rsync.
 	"""
 		self._watch.scan()
-
-if __name__ == '__main__':
-	import argparse, random
-
-	p = argparse.ArgumentParser(
-		formatter_class=argparse.RawDescriptionHelpFormatter,
-		description="Test the %s module\n%s" %
-		(os.path.splitext(os.path.basename(__file__))[0], watch.__doc__))
-
-	p.add_argument('-v', '--verbose', action='store_true', dest='verbose', help='Verbose logging for debugging')
-	p.add_argument('-q', '--quiet', action='store_true', dest='quiet', help='Warnings and errors only')
-	p.add_argument('-p', '--module-path', action='store', dest='module_path', help='Module path list (commonly $PYTHONPATH)')
-	p.add_argument('-s', '--show', action='store_true', dest='show',
-					help='Print the list of files that would be watched and exit')
-	p.add_argument('command', nargs='+', help='List of applications to watch')
-
-	p.set_defaults(verbose=False)
-	p.set_defaults(quiet=False)
-
-	args = p.parse_args()
-
-	log = logging.getLogger(__name__)
-	log.addHandler(logging.StreamHandler())
-	if args.verbose:
-		log.setLevel(logging.DEBUG)
-	if args.quiet:
-		log.setLevel(logging.WARNING)
-
-	snoop = watch(log=log, module_path=args.module_path)
-	for command in args.command:
-		snoop.add(command)
-
-	if args.show:
-		names = {}
-		for m in snoop.modules:
-			for name in snoop.modules[m]:
-				if name in names:
-					names[name].append(m)
-				else:
-					names[name] = [m]
-		for name in names:
-			print name+':'
-			for m in names[name]:
-				print "\t" + m
-		sys.exit(0)
-
-	#  test remove if we have a lot to choose from
-	if len(args.command) > 2:
-		rand_discard = args.command[random.randrange(len(args.command))]
-		print "Randomly discarding %s to test removal" % (rand_discard,)
-		snoop.remove(rand_discard)
-
-	print "Watching %d module%s for %d command%s" % (len(snoop.modules), '' if len(snoop.modules) == 1 else 's',
-							 len(snoop.names), '' if len(snoop.names) == 1 else 's')
-	while True:
-		if select.select([snoop], [], [], 60) == ([],[],[]):
-			log.debug("Select timed out")
-			continue
-		print 'Changes detected ...'
-		for name, path, module_list in snoop.get(timeout=0):
-			print '    ', name, module_list
-	raise SystemExit(0)
